@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-import os, re, logging, inspect
+import os, re, logging, inspect, traceback
 from inspect import ismethod, isfunction
 from AccessControl.PermissionRole import rolesForPermissionOn
 from AccessControl.SecurityManagement import noSecurityManager
@@ -46,7 +46,7 @@ from Products.statusmessages.interfaces import IStatusMessage
 from stxnext.staticdeployment.browser.preferences.staticdeployment import IStaticDeployment
 from stxnext.staticdeployment.interfaces import ITransformation, IDeploymentStep, IExtraDeploymentCondition, \
     IPostTransformation, IImageTransformation
-from stxnext.staticdeployment.utils import ConfigParser, get_config_path
+from stxnext.staticdeployment.utils import ConfigParser, get_config_path, reset_request
 
 
 try:
@@ -55,6 +55,11 @@ try:
 except ImportError:
     PLONE_RESOURCE_INSTALLED = False
 
+try:
+    from plone.resource.interfaces import IResourceDirectory
+except:
+    from zope.interface import Interface as IResourceDirectory
+
 
 log = logging.getLogger(__name__)
 
@@ -185,10 +190,17 @@ class StaticDeploymentUtils(object):
             # Condition added to keep compatibility with
             # existing transformations after the change in API
             log.debug('Processing %s post-transformation' % t_name)
-            if len(inspect.getargspec(t.__call__)[0]) == 3:
-                html = t(html, file_path)
-            else:
-                html = t(html)
+            try:
+                if len(inspect.getargspec(t.__call__)[0]) == 3:
+                    html = t(html, file_path)
+                else:
+                    html = t(html)
+            except:
+                if not file_path:
+                    file_path = ''
+                log.error('error in %s post-transformation(%s)\n%s' % (
+                    t_name, file_path, traceback.format_exc()
+                    ))
         return html
 
 
@@ -346,7 +358,13 @@ class StaticDeploymentUtils(object):
                     continue
                 # check if object is a normal page
                 is_page = brain.meta_type in self.page_types
-                self._deploy_content(obj, is_page=is_page)
+                try:
+                    self._deploy_content(obj, is_page=is_page)
+                except:
+                    log.error("error exporting object: %s\n%s" % (
+                        '/'.join(obj.getPhysicalPath()),
+                        traceback.format_exc())
+                    )
 
         ## find and run additional deployment steps
         self._applay_extra_deployment_steps(modification_date)
@@ -362,7 +380,6 @@ class StaticDeploymentUtils(object):
         registry_view = getMultiAdapter((self.context, self.request), name='resourceregistries_%s_view' % resource_name)
         registry = registry_view.registry()
         resources = getattr(registry_view, resource_type)()
-
         for resource in resources:
             filename = urlparse(resource['src'])[2]
             try:
@@ -370,8 +387,8 @@ class StaticDeploymentUtils(object):
             except TypeError:
                 log.exception("File '%s' not found when deploying '%s'!" % (filename, registry_type))
                 continue
-
-            self._write(filename, content)
+            # so html isn't added...
+            self._write(filename, content, omit_transform=True)
 
 
     def _deploy_skinstool_files(self, files):
@@ -399,7 +416,7 @@ class StaticDeploymentUtils(object):
                 filename, content = self._apply_image_transforms(filename, content)
             self._write(filename, content)
 
-
+    @reset_request
     def _deploy_views(self, views, is_page=False):
         """
         Deploy views of context as pages.
@@ -420,7 +437,12 @@ class StaticDeploymentUtils(object):
                     log.warning("Unable traverse to '%s'!" % context_path)
                     continue
 
-            content_obj = context.restrictedTraverse(view_name, None)
+            # plone.resource file system resource
+            if IResourceDirectory.providedBy(context):
+                content_obj = context[view_name]
+            else:
+                content_obj = context.restrictedTraverse(view_name, None)
+
             # get object's view content 
             if ismethod(content_obj) or isfunction(content_obj):
                 view = queryMultiAdapter((context, self.request), name=view_name)
@@ -439,6 +461,7 @@ class StaticDeploymentUtils(object):
             self._write(filename, content, fullview_path)
 
 
+    @reset_request
     def _render_obj(self, obj):
         """
         Render object to string.
@@ -522,14 +545,14 @@ class StaticDeploymentUtils(object):
                 if view:
                     try:
                         return view.context()
-                    except ContentProviderLookupError:
+                    except (ContentProviderLookupError, TypeError):
                         pass
 
                 view = obj.restrictedTraverse(view_name, None)
                 if view:
                     try:
                         return view.context()
-                    except AttributeError:
+                    except (AttributeError, TypeError):
                         try:
                             return view()
                         except Exception, error:
@@ -713,7 +736,10 @@ class StaticDeploymentUtils(object):
             if netloc and netloc != portal_url:
                 ## external link
                 continue
-
+            elif path.startswith('image/svg+xml;base64') or \
+                 path.startswith('image/png;base64'):
+                ## images defined in css
+                continue
             if path.startswith('/'):
                 objpath = path[1:]
             else:
@@ -727,10 +753,12 @@ class StaticDeploymentUtils(object):
             objpath_spl = objpath.split('/', 1)
             if objpath_spl[0] == 'plone' and len(objpath_spl) > 1:
                 objpath = objpath_spl[1]
+            # fix "../" in paths
+            objpath = os.path.normpath(objpath)
 
             if objpath in self.deployed_resources:
                 continue
-            obj = self.context.restrictedTraverse(objpath, None)
+            obj = self.context.unrestrictedTraverse(objpath, None)
             if objpath.rsplit('/', 1)[-1].split('.')[0] == 'image':
                 obj = self.context.restrictedTraverse(objpath.rsplit('.', 1)[0], None)
             if not obj:
@@ -750,14 +778,22 @@ class StaticDeploymentUtils(object):
             if not obj:
                 if '/@@images/' in objpath:
                     parent_path, image_name = objpath.split('/@@images/')
-                    parent_obj = self.context.restrictedTraverse(unquote(parent_path), None)
+                    parent_obj = self.context.unrestrictedTraverse(unquote(parent_path), None)
                     if parent_obj:
-                        fieldname, scalename = image_name.split('/')
+                        spl_img_name = image_name.split('/')
+                        if len(spl_img_name) == 1:
+                            # no scalename in path
+                            fieldname = spl_img_name[0]
+                            scalename = None
+                            objpath = '/'.join((parent_path, 'image.jpg'))
+                        else:
+                            fieldname, scalename = spl_img_name
+                            objpath = os.path.join(parent_path, '_'.join((fieldname, scalename)), 'image.jpg')
                         try:
                             images_view = getMultiAdapter((parent_obj, self.request), name='images')
                             field = images_view.field(fieldname)
-                            obj = field.getScale(parent_obj, scalename)
-                            objpath = os.path.join(parent_path, '_'.join((fieldname, scalename)), 'image.jpg')
+                            if field:
+                                obj = field.getScale(parent_obj, scalename)
                         except ComponentLookupError:
                             pass
             if not obj:
@@ -830,7 +866,8 @@ class StaticDeploymentUtils(object):
             log.exception("Error trying to dump data to '%s' file!" % filename)
             return
 
-        if RE_NOT_BINARY.search(filename) and not omit_transform:
+        if RE_NOT_BINARY.search(filename) and not omit_transform and \
+                not filename.endswith('.js') and not filename.endswith('.css'):
             pre_transformated_content = self._apply_transforms(content)
             post_transformated_content = self._apply_post_transforms(
                     pre_transformated_content, file_path=file_path)
